import { Config as ProxyOptions } from 'http-proxy-middleware';
declare type Cookies = {
    [key: string]: string;
};
export interface SecureCookieProxyOptions extends ProxyOptions {
    /**
     * Target proxy destination.
     */
    target: string;
    /**
     * HTTP status code indicating when auth cookies are needed (default: 401).
     */
    unauthorizedStatusCode?: number | number[];
    /**
     * The account name used to save cookies in system keychain or a local file.
     */
    keychainAccount?: string;
    /**
     * Additional processing on secure cookies before setting them to the client.
     */
    cookieRewrite?: (cookies: Cookies) => Cookies;
}
/**
 * Generate a proxy config that points to a remote host.
 */
export declare function secureCookieProxy(options: string | SecureCookieProxyOptions): ProxyOptions;
export default secureCookieProxy;
